package de.fahsel.dewis;

/**
 * Diese Klasse repräsentiert eine Verbandssmitgliedschaft. Auf Mitgliedschaften 
 * kann mit den entsprechenden Methoden an der {@link Player}-Klasse zugegriffen werden.
 * 
 * @see Player#getAssociationMemberships()
 * @see Player#getAssociationMembershipByZps(String)
 * 
 * @author Peter Fahsel
 *
 */
public class AssociationMembership extends AbstractMembership
{
	private Integer rank;
	private Player  evaluator;
	
	protected AssociationMembership(Association association, String rank, String evaluator)
	{
		super(association);
		setRank(rank);
		setEvaluator(evaluator);
	}
	
	protected AssociationMembership(Association association, Integer rank, String evaluator)
	{
		super(association);
		setRank(rank);
		setEvaluator(evaluator);
	}
	
	public Association getAssociation()
	{
		return (Association) getOrganisation();
	}
	
	/**
	 * @return Der Rang des Spielers innerhalb des Verbands
	 */
	public Integer getRank()
	{
		return rank;
	}

	protected void setRank(Integer rank)
	{
		this.rank = rank;
	}
	
	protected void setRank(String rank)
	{
		try
		{
			this.rank = Integer.parseInt(rank);
		}
		catch (Exception e)
		{
			this.rank = null;
		}
	}

	/**
	 * @return Der Auswerter
	 */
	public Player getEvaluator()
	{
		return evaluator;
	}

	protected void setEvaluator(Player evaluator)
	{
		this.evaluator = evaluator;
	}
	
	protected void setEvaluator(String evaluator)
	{
		if (evaluator.isEmpty())
		{
			this.evaluator = null;
		}
		else
		{
			try
			{
				this.evaluator = Player.getInstance(evaluator);
			} 
			catch (Exception e)
			{
				this.evaluator = null;
			}
		}
	}
}
