package de.fahsel.dewis.examples;

import java.io.IOException;
import java.util.Collection;
import java.util.List;

import de.fahsel.dewis.AssociationMembership;
import de.fahsel.dewis.ClubMembership;
import de.fahsel.dewis.DewisFacade;
import de.fahsel.dewis.Player;
import de.fahsel.dewis.Tournament;

/**
 * Dieses Beispiel lädt einen Spieler anhand seiner pkz und gibt Informationen
 * zu seinen Turnieren und Mitgliedschaften auf der Konsole aus.
 * 
 * @author Peter Fahsel
 *
 */
public class ExamplePlayer
{
	public static void main(String[] args) throws IOException
	{
		// Erzeugt dei DewisFacade über die auf die API des Schachbundes zugegriffen werden kann
		DewisFacade dewis = new DewisFacade();
		
		// Lädt den Spieler mit der pkz 10089054 (Frank Hoppe)
		Player player = dewis.getPlayer(10089054);
		
		// Gibt den Namen und die DWZ des Spielers aus
		System.out.println(player.getFirstName() + " " + player.getLastName() + " " + player.getDwz());
		
		// Lädt alle Turiere des Spielers
		List<Tournament> tournaments = player.getTournaments();
		System.out.println(" - Turniere");
		
		// Iteriert über die Turniere
		for (Tournament tournament: tournaments)
		{
			// Gibt den Namen des Turniers aus
			System.out.println("   - " + tournament.getName());
		}
		
		// Lädt die Vereinsmitgliedschaften des Spielers
		Collection<ClubMembership> clubMemberships = player.getClubMemberships();
		System.out.println(" - Vereinsmitgliedschaften");
		
		// Iteriert über die Vereinsmitgliedschaften
		for (ClubMembership clubMembership: clubMemberships)
		{
			// Gibt die Mitgliednummer des Spielers in diesem Verein und den Namen des Vereins aus
			System.out.println("   - " + clubMembership.getZps() + " " + clubMembership.getClub().getName());
		}
		
		// Lädt die Vereinsmitgliedschaften des Spielers
		Collection<AssociationMembership> associationMemberships = player.getAssociationMemberships();
		System.out.println(" - Verbandsmitgliedschaften");
		
		// Iteriert über die Verbandsmitgliedschaften
		for (AssociationMembership associationMembership: associationMemberships)
		{
			// Gibt den Rang des Spielers im Verband und den Namen des Verbands aus
			System.out.println("   - " + associationMembership.getRank() + ". " + associationMembership.getAssociation().getName());
		}
	}
}